
#include "window.hpp"

#include <iostream>
#include <string>
#include <stdexcept>

#include <GLFW/glfw3.h>

using namespace fggl::gfx;

static void glfw_error(int code, const char* description) {
	std::cerr << "[GLFW] " << code << " " << description << std::endl;
}

Context::Context() {
	int state = glfwInit();
	if ( state == GLFW_FALSE ) {
		const char** error;
		int code = glfwGetError(error);
		throw std::runtime_error( *error );
	}
}

Context::~Context() {
	glfwTerminate();
}

void Context::pollEvents() {
	glfwPollEvents();
}

Window::Window() : m_window(nullptr), m_input(nullptr) {
	m_window = glfwCreateWindow(1920, 1080, "main", NULL, NULL);
	glfwSetWindowUserPointer(m_window, this);
}

Window::~Window() {
	if ( m_window != nullptr ) {
		glfwDestroyWindow(m_window);
		m_window = nullptr;
	}
}

void Window::activate() {
	assert( m_window != nullptr );
	glfwMakeContextCurrent(m_window);
}

void Window::swap() {
	assert( m_window != nullptr );
	glfwSwapBuffers(m_window);
}
